#
# spec file for package python-xapp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define         skip_python2 1
%define         _name python3-xapp
Name:           python-xapp
Version:        2.4.2
Release:        2.8
Summary:        Python XApp library
License:        GPL-2.0-or-later
URL:            https://github.com/linuxmint/python3-xapp
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        setup.py
# PATCH-FEATURE-OPENSUSE python-xapp-xdgsu.patch -- Escalate privileges using xdg-su.
Patch0:         python-xapp-xdgsu.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-psutil
Requires:       xdg-utils
BuildArch:      noarch

%description
This project gathers the components which are common to multiple
desktop environments and required to implement cross-DE solutions.

%python_subpackages

%prep
%autosetup -p1 -n %{_name}-%{version}
cp %{SOURCE1} .
# let's change the version in setup.py
sed -i 's|version = "0.0.0",|version = "%{version}",|g' setup.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license COPYING
%doc debian/changelog
%{python_sitelib}/xapp/
%{python_sitelib}/python_xapp-*.egg-info

%changelog
* Mon Sep 23 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Aug 12 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 2.4.2:
  * Make python installation configurable for distro packaging (meson)
  * Revert "os.py: Add function to read the VERSION_CODENAME in /etc/os-release
  * Revert "os.py: rename get_os_release_codename()
  * os.py: rename get_os_release_codename() to get_os_release_info()
  * os.py: Add function to read the VERSION_CODENAME in /etc/os-release
- update to 2.4.1:
  * fix lintian error and build failure
- update to 2.4.0:
  * Use access() to test readability of /proc/cmdline
  * Use meson to build
- update to 2.2.2:
  * scale widget: Add the units to the value instead of appending it to
- update spec file to newer standards, add the older setup.py, so we
  can build it for multiple python versions
* Thu May 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Thu Dec  9 2021 andy great <andythe_great@pm.me>
- Update to version 2.2.1.
  * Fix typo
* Sun May 30 2021 andy great <andythe_great@pm.me>
- Update to version 2.2.0.
  * SettingsWidgets.py: Restrict Range increments to the 'step' amount.
  * Font chooser widget: add option to specify the level of font selection.
* Mon Dec  7 2020 andy great <andythe_great@pm.me>
- Update to version 2.0.2.
  * Allow adding separators to the combo box widget
* Sun Sep 27 2020 andy great <andythe_great@pm.me>
- Update to version 2.0.1.
  * Packaging: Rename source package
  * Remove python2 support.
  * Settings section: ensure that settings inside a revealer can be
    visible
* Sat Feb  8 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.8.1
  * icon chooser widget: fix kwargs to support current features
    correctly
- Changes from versio 1.8.0
  * Expose new features in the XAppIconChooserDialog to the
    settings widget (#10)
* Mon Jul  1 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.6.0:
  * Add GSettingsWidgets and SettingsWidgets (#7)
* Fri Mar 15 2019 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 1.4.0:
  * Bump to version 1.4.0.
* Thu Apr 19 2018 sor.alexei@meowr.ru
- Update to version 1.2.0:
  * Properly bump version in setup.py.
* Mon Jun 12 2017 sor.alexei@meowr.ru
- Update to version 1.0.1:
  * OS: Turn pkexec support into an opt-in and don't set
    DISPLAY/XAUTHORITY.
  * Add mate-polkit agent support.
  * run_with_admin_privs: Use pkexec as a last ditch chance.
  * Support polkit processname under Ubuntu 17.04.
  * OS: Add is_guest_session() and is_live_session().
- Add python-xapp-xdgsu.patch: Escalate privileges using xdg-su.
- Add xdg-utils to requirements for xdg-su.
* Thu May  4 2017 sor.alexei@meowr.ru
- Initial package.
